@@ -1,6 +1,8 @@
 from __future__ import absolute_import
 from __future__ import with_statement
 
+from anyjson import loads
+
 from django import forms
 from django.conf import settings
 from django.contrib import admin
@@ -88,8 +90,9 @@ class ModelMonitor(admin.ModelAdmin):
     def change_view(self, request, object_id, extra_context=None):
         extra_context = extra_context or {}
         extra_context.setdefault('title', self.detail_title)
-        return super(ModelMonitor, self).change_view(request, object_id,
-                                                     extra_context)
+        return super(ModelMonitor, self).change_view(
+            request, object_id, extra_context=extra_context,
+        )
 
     def has_delete_permission(self, request, obj=None):
         if not self.can_delete:
@@ -143,7 +146,7 @@ class TaskMonitor(ModelMonitor):
     ]
 
     class Media:
-        css = {'all': ('djcelery/style.css',)}
+        css = {'all': ('djcelery/style.css', )}
 
     @action(_('Revoke selected tasks'))
     def revoke_tasks(self, request, queryset):
@@ -268,6 +271,22 @@ def periodic_task_form():
                 raise exc
             return data
 
+        def _clean_json(self, field):
+            value = self.cleaned_data[field]
+            try:
+                loads(value)
+            except ValueError, exc:
+                raise forms.ValidationError(
+                    _('Unable to parse JSON: %s') % exc,
+                )
+            return value
+
+        def clean_args(self):
+            return self._clean_json('args')
+
+        def clean_kwargs(self):
+            return self._clean_json('kwargs')
+
     return PeriodicTaskForm
 
 
