@@ -20,12 +20,12 @@ def patch_thread_ident():
     # This patch make sure that we use real threads to get the ident which
     # is going to happen if we are using gevent or eventlet.
     # -- patch taken from gunicorn
-    if getattr(patch_thread_ident, "called", False):
+    if getattr(patch_thread_ident, 'called', False):
         return
     try:
         from django.db.backends import BaseDatabaseWrapper, DatabaseError
 
-        if "validate_thread_sharing" in BaseDatabaseWrapper.__dict__:
+        if 'validate_thread_sharing' in BaseDatabaseWrapper.__dict__:
             import thread
             _get_ident = thread.get_ident
 
@@ -37,13 +37,15 @@ def patch_thread_ident():
 
             def _validate_thread_sharing(self):
                 if (not self.allow_thread_sharing
-                    and self._thread_ident != _get_ident()):
-                        raise DatabaseError(DB_SHARED_THREAD % (
-                                self.alias, self._thread_ident, _get_ident()))
+                        and self._thread_ident != _get_ident()):
+                    raise DatabaseError(
+                        DB_SHARED_THREAD % (
+                            self.alias, self._thread_ident, _get_ident()),
+                    )
 
             BaseDatabaseWrapper.__init__ = _init
-            BaseDatabaseWrapper.validate_thread_sharing \
-                    = _validate_thread_sharing
+            BaseDatabaseWrapper.validate_thread_sharing = \
+                _validate_thread_sharing
 
         patch_thread_ident.called = True
     except ImportError:
@@ -53,21 +55,21 @@ patch_thread_ident()
 
 class CeleryCommand(BaseCommand):
     options = BaseCommand.option_list
-    skip_opts = ["--app", "--loader", "--config"]
+    skip_opts = ['--app', '--loader', '--config']
     keep_base_opts = False
 
     def get_version(self):
-        return "celery %s\ndjango-celery %s" % (celery.__version__,
+        return 'celery %s\ndjango-celery %s' % (celery.__version__,
                                                 djcelery.__version__)
 
     def execute(self, *args, **options):
-        broker = options.get("broker")
+        broker = options.get('broker')
         if broker:
             self.set_broker(broker)
         super(CeleryCommand, self).execute(*args, **options)
 
     def set_broker(self, broker):
-        os.environ["CELERY_BROKER_URL"] = broker
+        os.environ['CELERY_BROKER_URL'] = broker
 
     def run_from_argv(self, argv):
         self.handle_default_options(argv[2:])
@@ -77,15 +79,15 @@ class CeleryCommand(BaseCommand):
         acc = []
         broker = None
         for i, arg in enumerate(argv):
-            if "--settings=" in arg:
-                _, settings_module = arg.split("=")
-                os.environ["DJANGO_SETTINGS_MODULE"] = settings_module
-            elif "--pythonpath=" in arg:
-                _, pythonpath = arg.split("=")
+            if '--settings=' in arg:
+                _, settings_module = arg.split('=')
+                os.environ['DJANGO_SETTINGS_MODULE'] = settings_module
+            elif '--pythonpath=' in arg:
+                _, pythonpath = arg.split('=')
                 sys.path.insert(0, pythonpath)
-            elif "--broker=" in arg:
-                _, broker = arg.split("=")
-            elif arg == "-b":
+            elif '--broker=' in arg:
+                _, broker = arg.split('=')
+            elif arg == '-b':
                 broker = argv[i + 1]
             else:
                 acc.append(arg)
@@ -95,10 +97,10 @@ class CeleryCommand(BaseCommand):
 
     def die(self, msg):
         sys.stderr.write(msg)
-        sys.stderr.write("\n")
+        sys.stderr.write('\n')
         sys.exit()
 
     @property
     def option_list(self):
         return [x for x in self.options
-                    if x._long_opts[0] not in self.skip_opts]
+                if x._long_opts[0] not in self.skip_opts]
