@@ -22,10 +22,11 @@ from . import views
 
 task_pattern = r'(?P<task_id>[\w\d\-\.]+)'
 
-urlpatterns = patterns("",
+urlpatterns = patterns(
+    '',
     url(r'^%s/done/?$' % task_pattern, views.is_task_successful,
-        name="celery-is_task_successful"),
+        name='celery-is_task_successful'),
     url(r'^%s/status/?$' % task_pattern, views.task_status,
-        name="celery-task_status"),
+        name='celery-task_status'),
     url(r'^tasks/?$', views.registered_tasks, name='celery-tasks'),
 )
