@@ -5,7 +5,8 @@ from demoapp import views
 from django.contrib import admin
 admin.autodiscover()
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     # Example:
     # (r'^demoproject/', include('demoproject.foo.urls')),
 
